uncertainties
=============

..
    .. image:: https://travis-ci.org/lebigot/uncertainties.png
       :target: https://travis-ci.org/lebigot/uncertainties

This is the uncertainties Python package, which performs transparent
calculations with uncertainties (aka "error propagation"). This package
also calculates derivatives.

* Documentation: http://pythonhosted.org/uncertainties/
* Issues: https://github.com/lebigot/uncertainties/issues/
* Python Package Index entry: http://pypi.python.org/pypi/uncertainties/
* Code: https://github.com/lebigot/uncertainties/

GitHub
------

The current version of the ``master*`` branches in the Github
repository are bleeding-edge, but they are *working* versions that
passed the tests for all versions of Python starting at 2.4.

The ``master`` branch is for Python 2.6+ (and Python 3+ through
``2to3``), while the ``master_python2.3`` branch is for Python 2.3 to
2.5.

Other branches might be present in the GitHub repository, but they are
temporary and represent work in progress that does not necessarily run
properly yet.

License
-------

This package and its documentation are released under the `Revised BSD
License <LICENSE.txt>`_.
